#!/usr/bin/env Rscript

# Multiple plot function
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
require(ggplot2)
args = commandArgs(trailingOnly=TRUE)

theme_Publication <- function(base_size=14, base_family="helvetica") {
      library(grid)
      library(ggthemes)
      (theme_foundation(base_size=base_size, base_family=base_family)
       + theme(
#	           plot.title = element_text(face = "bold",
#                                         size = rel(1.2), hjust = 0.5),
               text = element_text(),
               panel.background = element_rect(colour = NA),
               plot.background = element_rect(colour = NA),
               panel.border = element_rect(colour = NA),
               axis.title = element_text(face = "bold",size = rel(1)),
               axis.title.y = element_text(angle=90,vjust =-2),
               axis.title.x = element_text(vjust = -0.5),
               axis.text = element_text(), 
               axis.line = element_line(colour="black"),
               axis.ticks = element_line(),
               panel.grid.major = element_line(colour="#f0f0f0"),
               panel.grid.minor = element_blank(),
               legend.key = element_rect(colour = NA),
               legend.position = "right",
               legend.direction = "vertical",
 #              legend.key.size= unit(0.2, "cm"),
#               legend.key.size= ,
#               legend.margin = unit(0.05, "cm"),
               legend.title = element_text(face="italic"),
#               plot.margin=unit(c(10,5,5,5),"mm"),
               strip.background=element_rect(colour="#f0f0f0",fill="#f0f0f0"),
               strip.text = element_text(face="bold")
          ) )
      
}


gridfile = args[1]
crdfile = args[2]
outname = args[3]
#plottitle = args[4]
min_ref = floor( as.numeric( args[4] )  )
max_x = floor(as.numeric(args[5]))

if (min_ref == 0)
{
  min_ref = 1
}

crds <- read.table(crdfile, header=1)
crds$size = crds$size*5
crds$outsize = crds$size+1
crds <- crds[with(crds, order(z)), ]

ref_step = min_ref*2.0/3.0

field <- read.table(gridfile, header=1)
field$ref[field$ref < -99999] <- c(-99999) 
field$ref[field$ref >  99999] <- c( 99999)
for ( i in which(is.na(field$ref)) )
{
  field$ref[i] <- (field$ref[i-1] + field$ref[i+1])/2.0
}
 
palette_v <- c("#d7191c", "#fdae61", "#ffffbf", "#abd9e9", "#2c7bb6")
palette_legend <- c(
                    sprintf("(%1.1f,+\u221e)", min_ref),
                    sprintf("(%1.1f,%1.1f)", min_ref-ref_step, min_ref),
                    sprintf("(-%1.1f,%1.1f)", min_ref-ref_step, min_ref-ref_step),
                    sprintf("(-%1.1f,-%1.1f)", min_ref, min_ref-ref_step),
                    sprintf("(-\u221e,-%1.1f)", min_ref)
                   )
names(palette_v) <- palette_legend
 
field$refcut <- cut(field$ref*627.5, c(-99999999999, -min_ref, -(min_ref-ref_step), (min_ref-ref_step), min_ref, 999999999999),
                   labels=rev(palette_legend)
                   )
field$refcut <- factor(field$refcut, levels=rev(levels(field$refcut)), ordered=TRUE)
field$refcnt <- field$ref*627.5
field$refcnt[field$refcnt > min_ref+20*ref_step] <- min_ref +20*ref_step + ref_step/4.0
field$refcnt[field$refcnt < -min_ref-20*ref_step] <- -min_ref - 20*ref_step - ref_step/4.0

p1 <- ggplot() + 
      geom_raster(data=field, aes(y,x, fill=refcut), interpolate=TRUE) + 
      geom_contour(data=field, aes(y,x,z=refcnt ), binwidth=ref_step/2, linetype='dashed', color='black') +
      scale_fill_manual("MEP, kcal/mol\u00B7e", values=palette_v) + 
      coord_fixed(ratio=1) + ggtitle(__plottitle__) +
      scale_x_continuous("X, \u212b", breaks=seq(-max_x,max_x,2), limits=c(-max_x,max_x)) + 
      scale_y_continuous("Y, \u212b",breaks=seq(-max_x,max_x,2), limits=c(-max_x,max_x))  +
      geom_vline(xintercept=seq(-10,10,2), linetype='dotted', color='gray') + 
      geom_hline(yintercept=seq(-10,10,2), linetype='dotted', color='gray') 
for (i in 1:length(crds$x) )
{
  t <- crds[i,]
  p1 <- p1+ geom_point(data=t, aes(x=y, y=x), color='black', size=t$outsize) + 
	geom_point(data=t, aes(x=y, y=x, color=color), color=t$color, size=t$size) + 
	annotate( geom="text", x=t$y, y=t$x, label=t$elem) 
}
p1 <- p1 + theme_Publication() + guides(fill = guide_legend(title.position="top", title.hjust = 0.5))
#ggsave(paste(sep="", outname, ".ref.png"), width=3.33, height=3.33, units='in')
ggsave(outname, width=6, height=5, units='in')
	

