#!/bin/bash

if [ -d "rules" ]; then
  rm -rf rules
fi
mkdir rules
cd rules

cat > templ.prules << "EOF"
Placement-rules:

atom: "*" m
atom: "N" mdzq
atom: "n" mdzq

atom: "S" __rule__
atom: "s" __rule__
atom: "o" __rule__

EOF

cat > templ.orules << "EOF"
Orient-rules:
rule: z "*"                                              /* any atom */
rule: a "[!#99X1][!#99]"                                 /* Br in CBr */
rule: a "[!#99X2]([!#99])[#99]"                          /* Br in CBr-Du */
rule: a "[!#99D1X4]-[!#99]"                              /* CH3 in CCH3 */
rule: a "[!#99]#[!#99]"                                  /* any in C#N C#C*/
rule: b "[!#99X1][!#99]=,:[!#99]"                        /* Br in C=C-Br */
rule: b "[!#99X2]([!#99]=,:[!#99])-[#99]"                /* Br in C=C-Br-Du */
rule: b "[!#99H3][!#99][!#99]"                           /* CH3 in C-C-CH3 */
rule: b "[!#99D1X4][!#99]=,:[!#99]"                      /* CH3 in C=C-CH3 */
rule: c "[!#99](@[!#99])@[!#99]"                         /* ring atoms */
rule: b "[!#99X1]=[!#99][!#99]"                          /* O in CC=O */
rule: b "[!#99X1]=[!#99][N,O,S]"                         /* carbonyl O in ester */
rule: a "[!#99X1]=[!#99X2]=[!#99]"                       /* O in C=C=O ketene */
rule: c "[!#99X2]([!#99])[!#99]"                         /* O in COC */
rule: c "[!#99X2](=[!#99X1])[!#99]"                      /* N in CN=O */
rule: d "[!#99X3](-[!#99])(-[!#99])-[!#99]"              /* N in CN(C)C */
rule: d "[!#99X4](-[!#99])(-[!#99])(-[!#99])-[#99]"      /* N in CN(C)C with dummy */
rule: b "[!#99X3](-[!#99])(-[!#99]=[!#99])-[!#99]"       /* N in amide */
rule: c "[!#99X3](-[!#99])(-[!#99]=[!#99])-[#1]"         /* N in NH in amide */
rule: c "[!#99X2](-[!#99])-[!#99]=[!#99]"                /* alcoholic O in ester */
rule: b "[!#99X3](=[!#99])(-[N,O,S])-[!#99]"             /* C in amide or ester */
rule: b "[!#99X3]([!#99])(=[!#99X1])=[!#99X1]"           /* -N(=O)=O nitro */
rule: b "[!#99X3+1]([!#99])(-[!#99X1-1])=[!#99X1]"       /* -N(=O)=O nitro */

rule: c "[n](@[!#99])@[!#99]"
rule: c "[NX3]([#1])([#1])[!#99]=,:[!#99]"     /* Conjugated NH2 */
rule: d "[NX3]([#1])([#1])[!#99]!=,!:[!#99]"   /* Non-conjugated NH2 */
rule: c "[N]([#6])[C]=O"                       /* N in amide */
rule: c "[NX3](=O)=O"                          /* N in nitro */
rule: b "[OX1]=N[C,c]"                         /* O in nitroso and nitro*/
rule: c "[NX2](=O)[C,c]"                       /* N in nitroso */
rule: b "C(=O)[N,O,S]"                         /* C in ester */
rule: __rule__ "[O,o]([!#99])[!#99]"
rule: __rule__ "[S,s]([!#99])[!#99]"
EOF

cat > mk.prules << "EOF"
Placement-rules:

atom: "*" m
EOF

sed 's|__rule__|m           |g' templ.prules >     m.prules
sed 's|__rule__|mdz         |g' templ.prules >   mdz.prules
sed 's|__rule__|mq          |g' templ.prules >    mq.prules
sed 's|__rule__|mq          |g' templ.prules >   mqr.prules
sed 's|__rule__|mqx         |g' templ.prules >   mqx.prules
sed 's|__rule__|mqz         |g' templ.prules >   mqz.prules
sed 's|__rule__|mqy         |g' templ.prules >   mqy.prules
sed 's|__rule__|mdzq        |g' templ.prules >  mdzq.prules
sed 's|__rule__|mdvq (1,1,0)|g' templ.prules > mdvqr.prules
sed 's|__rule__|mdzqx       |g' templ.prules > mdzqx.prules
sed 's|__rule__|mdzqz       |g' templ.prules > mdzqz.prules
sed 's|__rule__|mdzqy       |g' templ.prules > mdzqy.prules

sed 's|__rule__|c|g' templ.orules >    mk.orules
sed 's|__rule__|c|g' templ.orules >     m.orules
sed 's|__rule__|c|g' templ.orules >   mdz.orules
sed 's|__rule__|c|g' templ.orules >    mq.orules
sed 's|__rule__|f|g' templ.orules >   mqr.orules
sed 's|__rule__|c|g' templ.orules >   mqx.orules
sed 's|__rule__|c|g' templ.orules >   mqz.orules
sed 's|__rule__|c|g' templ.orules >   mqy.orules
sed 's|__rule__|c|g' templ.orules >  mdzq.orules
sed 's|__rule__|f|g' templ.orules > mdvqr.orules
sed 's|__rule__|c|g' templ.orules > mdzqx.orules
sed 's|__rule__|c|g' templ.orules > mdzqz.orules
sed 's|__rule__|c|g' templ.orules > mdzqy.orules

cd ..

for i in mol1 mol2 mol3 mol4 mol5
do
  rm -rf ${i}
  mkdir ${i}
  antechamber -fi mol2 -fo mol2 -i ${i}.mol2 -o ${i}.bcc.mol2 -pf y -at sybyl -c bcc > /dev/null 2>&1
  scripts/calc_resp ${i}.mol2 ${i}.4c5l.esp --clear
  mv ${i}.resp.mol2 ${i}.bcc.mol2 ${i}
  mmol2mol ${i}/${i}.resp.mol2 ${i}/${i}.resp.mmol -f
  mmol2mol ${i}/${i}.bcc.mol2 ${i}/${i}.bcc.mmol -f
  mult_fitter -I ${i}.mol2 -G ${i}.4c5l.esp -O ${i}/${i}.mk.mmol -p rules/mk.prules -o rules/mk.orules -f -b
  for j in m mdz mq mqr mqx mqy mqz mdzq mdvqr mdzqx mdzqy mdzqz
  do
    mult_fitter -I ${i}.mol2 -G ${i}.4c5l.esp -O ${i}/${i}.${j}.mmol -p rules/${j}.prules -o rules/${j}.orules -f
  done
done

echo "mol bcc resp mk m mdz mq mqr mqx mqy mqz mdzq mdvqr mdzqx mdzqy mdzqz" > results.txt
for i in  mol1 mol2 mol3 mol4 mol5
do
  line="${i} "
  for j in bcc resp mk m mdz mq mqr mqx mqy mqz mdzq mdvqr mdzqx mdzqy mdzqz
  do
    rmsd=$(mep_rmsd -m ${i}/${i}.${j}.mmol -g ${i}.4c5l.esp | awk '{ print $3 }')
    line="${line} ${rmsd} "
  done
  echo ${line} >> results.txt
done

