#!/usr/bin/python3

from openbabel import *
from ElectrostaticTools import *
import sys
import os.path
import argparse

parser = argparse.ArgumentParser(description='Prepares data.frame file with MEP.')
parser.add_argument('-M', '--molecule', required=True, help="Molecule file")
parser.add_argument('-G', '--grids', required=True, action='append',nargs=2, metavar=('grid1','grid2'), help="Two grid files")
parser.add_argument('-O', '--output', required=True, action='append',nargs=3, metavar=('ref', 'mep', 'err'), help="Output names")
parser.add_argument('-C', '--coords', required=True, help="Outfile for coordinates")

args = parser.parse_args()

bohr = 0.52917721

mol = GeneralMultipoledMolecule()
grid1 = Grid()
grid2 = Grid()

mol.readMe(args.molecule)
grid1.fromESP(args.grids[0][0])
grid2.fromESP(args.grids[0][1])

# determine grid dimensions
orign = Vector3()
xvec = Vector3()
yvec = Vector3()
nx=0


step = (grid1.lattice(0)-grid1.lattice(1)).length()*2

for i in range(1, grid1.size()):
  a = grid1.lattice(i-1)
  b = grid1.lattice(i)
  if (a-b).length() > step :
    nx=i
    orign = a
    xvec = grid1.lattice(0)
    yvec = grid1.lattice(grid1.size()-1)
    break

step = (orign - xvec).length() / nx * bohr;
ny = int( grid1.size() / nx );

xv = (xvec-orign)
yv = (yvec-orign)
cent = (orign + xv*0.5 + yv*0.5)*bohr
xv.normalize()
yv.normalize()
zv = xv.vec(yv)

outref = open(args.output[0][0], 'w')
outmep = open(args.output[0][1], 'w')
outerr = open(args.output[0][2], 'w')

outref.write("x y ref\n")
outmep.write("x y ref\n")
outerr.write("x y ref\n")

min_ref = 0
max_err = 0
min_err = 0

for i in range (0, nx):
  for j in range (0, ny):
    x = (i-nx/2.0)*step
    y = (j-ny/2.0)*step
    ref = grid1.field(i+nx*j)
    mep = grid2.field(i+nx*j)
    err = mep - ref
    if ( x*x + (y-2.0)*(y-2.0) ) < 1.0 :
      if ref < min_ref :  
        min_ref = ref   
        min_err = err   
    outref.write("{:.7} {:.7} {:.7}\n".format(x, y, ref))
    outmep.write("{:.7} {:.7} {:.7}\n".format(x, y, mep))
    outerr.write("{:.7} {:.7} {:.7}\n".format(x, y, err))

print("{} {}".format(abs(min_ref*627.5), abs(min_err*627.5)))

crds = open(args.coords, 'w')
crds.write("x y z elem size color\n")
for atom in OBMolAtomIter(mol):
  patom = Vector3(atom.GetX(), atom.GetY(), atom.GetZ())
  vec = patom - cent
  elem = etab.GetSymbol(atom.GetAtomicNum())
  size = etab.GetVdwRad(atom.GetAtomicNum())
  col = etab.GetRGB(atom.GetAtomicNum())
  color = [ int(col[0]*255), int(col[1]*255), int(col[2]*255)  ]
  crds.write("{:.7} {:.7} {:.7} \"{}\" {:.2} \"#{:02X}{:02X}{:02X}\"\n".format(\
                 -vec*xv, vec*yv, vec*zv, elem, size, color[0], color[1], color[2])) 

 
